﻿<?php
defined('JPATH_PLATFORM') or die('Restricted acccess');

require_once(JPATH_COMPONENT_SITE.DIRECTORY_SEPARATOR.'utils.form2content.php');
require_once(JPATH_COMPONENT_SITE.DIRECTORY_SEPARATOR.'shared.form2content.php');
require_once(JPATH_COMPONENT_SITE.DIRECTORY_SEPARATOR.'class.form2content.php');

jimport('joomla.application.component.modeladmin');

class Form2ContentModelProjectField extends JModelAdmin
{
	protected $text_prefix = 'COM_FORM2CONTENT';

	public function getTable($type = 'ProjectField', $prefix = 'Form2ContentTable', $config = array())
	{
		return JTable::getInstance($type, $prefix, $config);
	}
	
	public function getItem($pk = null)
	{
		if ($item = parent::getItem($pk)) 
		{
			// Convert the settings field to an array.
			$registry = new JRegistry;
			$registry->loadString($item->settings);			
			$item->settings = $registry->toArray();
			
			if(!$item->projectid)
			{
				$item->projectid = JFactory::getApplication()->input->getInt('projectid');
			}
		}

		return $item;
	}
	
	public function getForm($data = array(), $loadData = true)
	{
		// Get the form.
		$form = $this->loadForm('com_form2content.projectfield', 'projectfield', array('control' => 'jform', 'load_data' => $loadData));
		
		if ($id = (int)$this->getState('projectfield.id')) 
		{
			// Existing record. Can't change field type anymore'.
			$form->setFieldAttribute('fieldtypeid', 'readonly', 'true');
		}
		
		if (empty($form)) 
		{
			return false;
		}

		return $form;
	}	

	protected function loadFormData()
	{
		// Check the session for previously entered form data.
		$data = JFactory::getApplication()->getUserState('com_form2content.edit.projectfield.data', array());

		if (empty($data)) 
		{
			$data = $this->getItem();
		}

		return $data;
	}

	public function save($data, $useRequestData = true)
	{
		$fieldPrefix = array(	F2C_FIELDTYPE_SINGLELINE => 'slt',
								F2C_FIELDTYPE_MULTILINETEXT => 'mlt',
								F2C_FIELDTYPE_MULTILINEEDITOR => 'mle',
								F2C_FIELDTYPE_SINGLESELECTLIST => 'ssl', 
								F2C_FIELDTYPE_IMAGE => 'img',
								F2C_FIELDTYPE_HYPERLINK => 'lnk',
								F2C_FIELDTYPE_INFOTEXT => 'inf');

		$settingsCount = count($data['settings']);
				
		foreach($data['settings'] as $key => $value)
		{
			// TODO: why doesn't $key == 'requiredfield' work?
			if(strstr($key, 'requiredfield') || $key == 'error_message_required')
			{
				continue;
			}
			
			if(!(strpos($key, $fieldPrefix[(int)$data['fieldtypeid']]) === 0))
			{
				unset($data['settings'][$key]);
			}
		}

		switch((int)$data['fieldtypeid'])
		{
			case F2C_FIELDTYPE_INFOTEXT:
				$tmpData = JFactory::getApplication()->input->get('jform', array(), 'array');
				
				if(count($tmpData))
				{
					$data['settings']['inf_text'] = $tmpData['settings']['inf_text'];
				}
				break;
			
			case F2C_FIELDTYPE_MULTILINETEXT:
				if((int)$data['settings']['mlt_max_num_chars'] == 0)
				{
					$data['settings']['mlt_max_num_chars'] = '';
				}
				break;
				
			case F2C_FIELDTYPE_SINGLESELECTLIST:
				if($useRequestData)
				{
					$data['settings']['ssl_options'] = $this->getOptionsArray('tblSingleSelectKvpRowKey', true);
				}
				break;			
		}
		
		if(parent::save($data))
		{
			if(F2cFactory::getConfig()->get('generate_sample_template'))
			{
				F2C_AdminHelper::generateSampleTemplate((int)$data['projectid']);
			}			
		}
		else
		{
			return false;
		}	
		
		return true;
	}
	
	public function copy()
	{
		$jinput					= JFactory::getApplication()->input;
		$cids 					= $jinput->get('cid', array(0), 'array');
		$contentTypeId 			= $jinput->getInt('projectid');
		$contentTypeFieldRow 	= $this->getTable('ProjectField');
		
		if(count($cids))
		{
			$db = $this->getDbo();
			$query = $db->getQuery(true);
	
			$query->select('*');
			$query->from('`#__f2c_projectfields`');
			$query->where('id IN (' . implode(',', $cids) . ')');
			
			$db->setQuery($query->__toString());	
			$contentTypeFields = $db->loadObjectList();
			
			foreach($contentTypeFields as $contentTypeField)
			{
				if (!$contentTypeFieldRow->bind((array)$contentTypeField)) 
				{
					$this->setError($contentTypeFieldRow->getError());
					return false;
				}

				$contentTypeFieldRow->id 		= 0; // force insert
				$contentTypeFieldRow->fieldname = $contentTypeFieldRow->fieldname . '_copy';
				$contentTypeFieldRow->projectid = $contentTypeId;
				$contentTypeFieldRow->ordering 	= 0;
			
				if(!$contentTypeFieldRow->store())
				{
					$this->setError($contentTypeFieldRow->getError());
					return false;
				}								
			}
			
			if(F2cFactory::getConfig()->get('generate_sample_template'))
			{
				F2C_AdminHelper::generateSampleTemplate((int)$contentTypeId);
			}			
			
			$cache = JFactory::getCache('com_form2content');
			$cache->clean();			
		}
		
		return true;		
	}
	
	protected function prepareTable($table)
	{
		// Reorder the Content Type fields within the Content Type so the new article is Content Type field
		if (empty($table->id)) 
		{
			$table->reorder('projectid = '.(int) $table->projectid);
		}
	}
	
	protected function getReorderConditions($table = null)
	{
		$condition = array();
		$condition[] = 'projectid = '.(int) $table->projectid;
		return $condition;
	}
	
	private function getOptionsArray($tableId, $hasValue = false)
	{
		$options 	= array();
		$jinput 	= JFactory::getApplication()->input;
		$rowKeys 	= $jinput->get($tableId, array(), 'array');
		
		if(count($rowKeys))
		{
			foreach($rowKeys as $rowKey)
			{
				$key = $jinput->getString($rowKey . 'key');

				if($key != '')
				{
					if(!$options || !array_key_exists($key, $options))
					{	
						if($hasValue)
						{
							$options[$key] = $jinput->get($rowKey.'val', '', 'RAW');
						}
						else
						{
							$options[$key] = $key;
						}
					}
				}						
			}
		}

		return $options;		
	}
	
	public function delete(&$pks)
	{
		// Initialise variables.
		$user			= JFactory::getUser();
		$f2cConfig 		= F2cFactory::getConfig();
		$pks			= (array) $pks;
		$table			= $this->getTable();
		$contentTypeId	= -1;
		
		// Iterate the items to delete each one.
		foreach ($pks as $i => $pk) 
		{
			if ($table->load($pk)) 
			{
				if ($this->canDelete($table)) 
				{
					$context = $this->option.'.'.$this->name;

					if($table->fieldtypeid == F2C_FIELDTYPE_IMAGE)
					{
						F2C_Image::deleteContentTypeFieldImages($pk);	
					}
					
					if($f2cConfig->get('generate_sample_template'))
					{
						$contentTypeId = $table->projectid;
					}			

					$query = $this->_db->getQuery(true);
	
					$query->delete('#__f2c_fieldcontent');
					$query->where('fieldid=' . (int)$pk);
					
					$this->_db->setQuery($query->__toString());
						
					if(!$this->_db->execute())
					{
						$this->setError($this->_db->getError());
						return false;
					}					
					
					if (!$table->delete($pk)) 
					{
						$this->setError($table->getError());
						return false;
					}
					
					if($f2cConfig->get('generate_sample_template'))
					{
						F2C_AdminHelper::generateSampleTemplate((int)$contentTypeId);
					}			
				} 
				else
				{
					// Prune items that you can't change.
					unset($pks[$i]);
					$error = $this->getError();
					if ($error) 
					{
						JFactory::getApplication()->enqueueMessage($error, 'notice');
					}
					else 
					{
						JFactory::getApplication()->enqueueMessage(JText::_('JLIB_APPLICATION_ERROR_DELETE_NOT_PERMITTED'), 'notice');
					}
				}
			} 
			else 
			{
				$this->setError($table->getError());
				return false;
			}
		}

		// Clear the component's cache
		$cache = JFactory::getCache($this->option);
		$cache->clean();

		return true;
	}
}
?>